@@ -40,7 +40,7 @@ use Cwd 'abs_path';
 use File::Path qw(make_path remove_tree);
 use File::stat;
 
-our $VERSION = "0.21";
+our $VERSION = "0.22";
 
 use App::LXC::Container::Data;
 use App::LXC::Container::Mounts;
@@ -335,6 +335,7 @@ sub _make_lxc_path($$)
 	my ($mode, $uid, $gid) = ($stat->mode, $stat->uid, $stat->gid);
 	if (-d)
 	{
+	    $mode |= 0200;	# prevent blocking ourselves later on
 	    if (-l)
 	    {
 		# links can be arbitrarily deep, so we use make_path on the
@@ -861,7 +862,6 @@ sub _write_lxc_configuration($)
 		    $header = 1;
 		}
 		say($out
-#		    '# created empty: ', $key);
 		    'lxc.mount.entry = tmpfs ', substr($key, 1),
 		    ' tmpfs create=dir,rw 0 0');
 		$mounts->mount_point($key, EMPTY);
